#!/usr/bin/env python
#
# Data Quality Checker also known as DQC
#
# Read the README.md for more detailed information
#
#       Barcelona Supercomputing Center - Centro Nacional de Supercomputacion
#       Earth Sciences Department - Computational Earth Sciences
#     
#     Authors: 
#       Joan Sala Calero (joan.sala@bsc.es)

import os
import json

"""
Write fields to a JSON obj and reset
"""
def write_and_reset(json_obj, varname, key, key_u, key_cf, defs, val_k, val_v):
	json_obj[key] = {
		'varname': varname,
		'unit': key_u,
		'cf': key_cf,
		'grib_codes': defs
	}			

	# Reset values
	varname = None
	key = None
	val_k = None
	val_v = None	
	defs = dict()
	return key, val_k, val_v, defs

"""
Convert from pseudo-format to a python dictionary and save to file
"""
def convert_to_json(param_file, units_file, cf_file, json_file):

	with open(param_file, 'r') as fp, open(units_file, 'r') as fu, open(cf_file, 'r') as fc:

		# Skip first line (autogenerated comment)
		line = fp.readline()
		line_u = fu.readline()
		line_c = fc.readline()
		
		# Initial conditions
		json_obj = dict()
		varname = None
		key = None
		val_k = None
		val_v = None
		defs = dict()

		while line and line_u:

			# Read next line
			line = fp.readline()
			line_u = fu.readline()
			line_c = fc.readline()

			# Starts with variable name
			if '#' in line:

				# Add if fields complete
				if not(varname is None or key is None or val_k is None or val_v is None):
					key, val_k, val_v, defs = write_and_reset(
						json_obj, varname, key, key_u, key_cf, defs, val_k, val_v)	

				# Next varname
				varname = line.replace('#', '').strip()
			elif '= {' in line:
				key = line.split('=')[0].replace('\'', '').strip()
				key_u = line_u.split('=')[0].replace('\'', '').strip()
				key_cf = line_c.split('=')[0].replace('\'', '').strip()		
			elif ';' in line:
				val_k = line.split('=')[0].replace('\t', '').strip()
				val_v = line.split('=')[1].replace(';', '').strip()
				defs[val_k] = val_v


		# Last one
		key, val_k, val_v, defs = write_and_reset(json_obj, varname, key, key_u, key_cf, defs, val_k, val_v)		
		
		# Save to JSON
		with open(json_file, 'w') as fo:
			json.dump(json_obj, fo, indent=2)


# Directory where definitions are + script
grib_dir = os.path.dirname(os.path.realpath(__file__))

convert_to_json(
	os.path.join(grib_dir, 'grib1_paramId.def'), 
	os.path.join(grib_dir, 'grib1_units.def'), 
	os.path.join(grib_dir, 'grib1_cfVarName.def'), 
	os.path.join(grib_dir, 'grib1.json'))

convert_to_json(
	os.path.join(grib_dir, 'grib2_paramId.def'), 
	os.path.join(grib_dir, 'grib2_units.def'), 
	os.path.join(grib_dir, 'grib2_cfVarName.def'), 
	os.path.join(grib_dir, 'grib2.json'))
